desert package
==============

Submodules
----------

desert.exceptions module
------------------------

.. automodule:: desert.exceptions
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: desert
   :members:
   :undoc-members:
   :show-inheritance:
